==> lxqt-runner_0.14.1.orig.tar.xz: lxqt-runner-0.14.1/translations/lxqt-runner_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Anwendungsstarter-Einstellungen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Positionierung:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Anzeigen auf:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Verlauf zuerst anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Verlauf speichern/anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Hinweis&lt;/b&gt;: Die Größe von Bedienelementen auf höchster Ebene ist auf 2/3 der Höhe und Breite des Schreibtisches beschränkt.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Liste anzeigen mit:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> Element(e)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Tastenkürzel:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Bildschirmoberkante</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Bildschirmmitte</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Focused screen</source>
        <translation>Fokussierter Bildschirm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="72"/>
        <source>Always on screen %1</source>
        <translation>Immer auf Bildschirm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="81"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Anwendungsstarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="94"/>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="98"/>
        <source>Clear History</source>
        <translation>Verlauf löschen</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="351"/>
        <source>Show/hide runner dialog</source>
        <translation>Zeige/verberge Runnerdialog</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="824"/>
        <source>Mathematics</source>
        <translation>Mathematik</translation>
    </message>
</context>
</TS>

==> lxqt-runner_0.15.0.orig.tar.xz: lxqt-runner-0.15.0/translations/lxqt-runner_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Anwendungsstarter-Einstellungen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Positionierung:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Anzeigen auf:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Verlauf zuerst anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Verlauf speichern/anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Hinweis&lt;/b&gt;: Die Größe von Bedienelementen auf höchster Ebene ist auf 2/3 der Höhe und Breite der Arbeitsfläche beschränkt.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Liste anzeigen mit:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> Element(e)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Tastenkürzel:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Bildschirmoberkante</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Bildschirmmitte</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Focused screen</source>
        <translation>Fokussierter Bildschirm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="72"/>
        <source>Always on screen %1</source>
        <translation>Immer auf Bildschirm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="81"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Anwendungsstarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="102"/>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="106"/>
        <source>Clear History</source>
        <translation>Verlauf löschen</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="359"/>
        <source>Show/hide runner dialog</source>
        <translation>Zeige/verberge Runnerdialog</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="845"/>
        <source>Mathematics</source>
        <translation>Mathematik</translation>
    </message>
</context>
</TS>
